==> zio-aws-iam_3-5.17.121.2-sources.jar: zio/aws/iam/model/CreatePolicyVersionResponse.scala <==
package zio.aws.iam.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreatePolicyVersionResponse(
    policyVersion: Option[zio.aws.iam.model.PolicyVersion] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse = {
    import CreatePolicyVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
      .builder()
      .optionallyWith(policyVersion.map(value => value.buildAwsValue()))(
        _.policyVersion
      )
      .build()
  }
  def asReadOnly: zio.aws.iam.model.CreatePolicyVersionResponse.ReadOnly =
    zio.aws.iam.model.CreatePolicyVersionResponse.wrap(buildAwsValue())
}
object CreatePolicyVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.CreatePolicyVersionResponse =
      zio.aws.iam.model.CreatePolicyVersionResponse(
        policyVersion.map(value => value.asEditable)
      )
    def policyVersion: Option[zio.aws.iam.model.PolicyVersion.ReadOnly]
    def getPolicyVersion
        : ZIO[Any, AwsError, zio.aws.iam.model.PolicyVersion.ReadOnly] =
      AwsError.unwrapOptionField("policyVersion", policyVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
  ) extends zio.aws.iam.model.CreatePolicyVersionResponse.ReadOnly {
    override val policyVersion
        : Option[zio.aws.iam.model.PolicyVersion.ReadOnly] = scala
      .Option(impl.policyVersion())
      .map(value => zio.aws.iam.model.PolicyVersion.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
  ): zio.aws.iam.model.CreatePolicyVersionResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iam_3-5.17.295.2-sources.jar: zio/aws/iam/model/CreatePolicyVersionResponse.scala <==
package zio.aws.iam.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreatePolicyVersionResponse(
    policyVersion: Optional[zio.aws.iam.model.PolicyVersion] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse = {
    import CreatePolicyVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
      .builder()
      .optionallyWith(policyVersion.map(value => value.buildAwsValue()))(
        _.policyVersion
      )
      .build()
  }
  def asReadOnly: zio.aws.iam.model.CreatePolicyVersionResponse.ReadOnly =
    zio.aws.iam.model.CreatePolicyVersionResponse.wrap(buildAwsValue())
}
object CreatePolicyVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.CreatePolicyVersionResponse =
      zio.aws.iam.model.CreatePolicyVersionResponse(
        policyVersion.map(value => value.asEditable)
      )
    def policyVersion: Optional[zio.aws.iam.model.PolicyVersion.ReadOnly]
    def getPolicyVersion
        : ZIO[Any, AwsError, zio.aws.iam.model.PolicyVersion.ReadOnly] =
      AwsError.unwrapOptionField("policyVersion", policyVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
  ) extends zio.aws.iam.model.CreatePolicyVersionResponse.ReadOnly {
    override val policyVersion
        : Optional[zio.aws.iam.model.PolicyVersion.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.policyVersion())
        .map(value => zio.aws.iam.model.PolicyVersion.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.CreatePolicyVersionResponse
  ): zio.aws.iam.model.CreatePolicyVersionResponse.ReadOnly = new Wrapper(impl)
}
